# pulp_ansible-client
Fetch, Upload, Organize, and Distribute Software Packages

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 0.7.4
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pulpcore.client.pulp_ansible
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pulpcore.client.pulp_ansible
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://pulp
# See configuration.py for a list of all supported configuration parameters.
configuration = pulpcore.client.pulp_ansible.Configuration(
    host = "http://pulp"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = pulpcore.client.pulp_ansible.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Configure API key authorization: cookieAuth
configuration = pulpcore.client.pulp_ansible.Configuration(
    host = "http://pulp",
    api_key = {
        'Session': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Session'] = 'Bearer'


# Enter a context with an instance of the API client
with pulpcore.client.pulp_ansible.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pulpcore.client.pulp_ansible.AnsibleCollectionsApi(api_client)
    limit = 56 # int | Number of results to return per page. (optional)
name = 'name_example' # str |  (optional)
namespace = 'namespace_example' # str |  (optional)
offset = 56 # int | The initial index from which to return the results. (optional)
ordering = 'ordering_example' # str | Which field to use when ordering the results. (optional)
fields = 'fields_example' # str | A list of fields to include in the response. (optional)
exclude_fields = 'exclude_fields_example' # str | A list of fields to exclude from the response. (optional)

    try:
        # List collections
        api_response = api_instance.list(limit=limit, name=name, namespace=namespace, offset=offset, ordering=ordering, fields=fields, exclude_fields=exclude_fields)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AnsibleCollectionsApi->list: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AnsibleCollectionsApi* | [**list**](docs/AnsibleCollectionsApi.md#list) | **GET** /pulp/api/v3/ansible/collections/ | List collections
*AnsibleCollectionsApi* | [**upload_collection**](docs/AnsibleCollectionsApi.md#upload_collection) | **POST** /ansible/collections/ | Upload a collection
*AnsibleCopyApi* | [**copy_content**](docs/AnsibleCopyApi.md#copy_content) | **POST** /pulp/api/v3/ansible/copy/ | Copy content
*ApiCollectionsApi* | [**get**](docs/ApiCollectionsApi.md#get) | **GET** {ansible_collection_href}api/v2/collections/ | 
*ApiCollectionsApi* | [**post**](docs/ApiCollectionsApi.md#post) | **POST** {ansible_collection_href}api/v2/collections/ | 
*ApiRolesApi* | [**get**](docs/ApiRolesApi.md#get) | **GET** {ansible_role_href}api/v1/roles/ | 
*CollectionImportApi* | [**read**](docs/CollectionImportApi.md#read) | **GET** {ansible_collection_import_href} | Inspect a collection import
*ContentCollectionVersionsApi* | [**create**](docs/ContentCollectionVersionsApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_versions/ | Create a collection version
*ContentCollectionVersionsApi* | [**list**](docs/ContentCollectionVersionsApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_versions/ | List collection versions
*ContentCollectionVersionsApi* | [**read**](docs/ContentCollectionVersionsApi.md#read) | **GET** {ansible_collection_version_href} | Inspect a collection version
*ContentRolesApi* | [**create**](docs/ContentRolesApi.md#create) | **POST** /pulp/api/v3/content/ansible/roles/ | Create a role
*ContentRolesApi* | [**list**](docs/ContentRolesApi.md#list) | **GET** /pulp/api/v3/content/ansible/roles/ | List roles
*ContentRolesApi* | [**read**](docs/ContentRolesApi.md#read) | **GET** {ansible_role_href} | Inspect a role
*DistributionsAnsibleApi* | [**create**](docs/DistributionsAnsibleApi.md#create) | **POST** /pulp/api/v3/distributions/ansible/ansible/ | Create an ansible distribution
*DistributionsAnsibleApi* | [**delete**](docs/DistributionsAnsibleApi.md#delete) | **DELETE** {ansible_ansible_distribution_href} | Delete an ansible distribution
*DistributionsAnsibleApi* | [**list**](docs/DistributionsAnsibleApi.md#list) | **GET** /pulp/api/v3/distributions/ansible/ansible/ | List ansible distributions
*DistributionsAnsibleApi* | [**partial_update**](docs/DistributionsAnsibleApi.md#partial_update) | **PATCH** {ansible_ansible_distribution_href} | Update an ansible distribution
*DistributionsAnsibleApi* | [**read**](docs/DistributionsAnsibleApi.md#read) | **GET** {ansible_ansible_distribution_href} | Inspect an ansible distribution
*DistributionsAnsibleApi* | [**update**](docs/DistributionsAnsibleApi.md#update) | **PUT** {ansible_ansible_distribution_href} | Update an ansible distribution
*GalaxyDetailApi* | [**get**](docs/GalaxyDetailApi.md#get) | **GET** {ansible_collection_href} | 
*PulpAnsibleApiApi* | [**get**](docs/PulpAnsibleApiApi.md#get) | **GET** /pulp_ansible/galaxy/{path}/api/ | 
*PulpAnsibleGalaxyApiCollectionsApi* | [**list**](docs/PulpAnsibleGalaxyApiCollectionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/ | 
*PulpAnsibleGalaxyApiCollectionsApi* | [**read**](docs/PulpAnsibleGalaxyApiCollectionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleGalaxyApiCollectionsApi* | [**update**](docs/PulpAnsibleGalaxyApiCollectionsApi.md#update) | **PATCH** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleGalaxyApiV2VersionsApi* | [**get**](docs/PulpAnsibleGalaxyApiV2VersionsApi.md#get) | **GET** /pulp_ansible/galaxy/{path}/api/v2/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleGalaxyApiV3AllApi* | [**list**](docs/PulpAnsibleGalaxyApiV3AllApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collection_versions/all/ | 
*PulpAnsibleGalaxyApiV3AllApi* | [**list_0**](docs/PulpAnsibleGalaxyApiV3AllApi.md#list_0) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/all/ | 
*PulpAnsibleGalaxyApiV3CollectionsApi* | [**create**](docs/PulpAnsibleGalaxyApiV3CollectionsApi.md#create) | **POST** /pulp_ansible/galaxy/{path}/api/v3/artifacts/collections/ | Upload a collection
*PulpAnsibleGalaxyApiV3CollectionsDocsBlobApi* | [**read**](docs/PulpAnsibleGalaxyApiV3CollectionsDocsBlobApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/{version}/docs-blob/ | 
*PulpAnsibleGalaxyApiV3VersionsApi* | [**list**](docs/PulpAnsibleGalaxyApiV3VersionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/ | 
*PulpAnsibleGalaxyApiV3VersionsApi* | [**read**](docs/PulpAnsibleGalaxyApiV3VersionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleGalaxyV3Api* | [**read**](docs/PulpAnsibleGalaxyV3Api.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/ | 
*PulpAnsibleTagsApi* | [**list**](docs/PulpAnsibleTagsApi.md#list) | **GET** /pulp/api/v3/pulp_ansible/tags/ | List tags
*RemotesCollectionApi* | [**create**](docs/RemotesCollectionApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/collection/ | Create a collection remote
*RemotesCollectionApi* | [**delete**](docs/RemotesCollectionApi.md#delete) | **DELETE** {ansible_collection_remote_href} | Delete a collection remote
*RemotesCollectionApi* | [**list**](docs/RemotesCollectionApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/collection/ | List collection remotes
*RemotesCollectionApi* | [**partial_update**](docs/RemotesCollectionApi.md#partial_update) | **PATCH** {ansible_collection_remote_href} | Update a collection remote
*RemotesCollectionApi* | [**read**](docs/RemotesCollectionApi.md#read) | **GET** {ansible_collection_remote_href} | Inspect a collection remote
*RemotesCollectionApi* | [**update**](docs/RemotesCollectionApi.md#update) | **PUT** {ansible_collection_remote_href} | Update a collection remote
*RemotesRoleApi* | [**create**](docs/RemotesRoleApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/role/ | Create a role remote
*RemotesRoleApi* | [**delete**](docs/RemotesRoleApi.md#delete) | **DELETE** {ansible_role_remote_href} | Delete a role remote
*RemotesRoleApi* | [**list**](docs/RemotesRoleApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/role/ | List role remotes
*RemotesRoleApi* | [**partial_update**](docs/RemotesRoleApi.md#partial_update) | **PATCH** {ansible_role_remote_href} | Update a role remote
*RemotesRoleApi* | [**read**](docs/RemotesRoleApi.md#read) | **GET** {ansible_role_remote_href} | Inspect a role remote
*RemotesRoleApi* | [**update**](docs/RemotesRoleApi.md#update) | **PUT** {ansible_role_remote_href} | Update a role remote
*RepositoriesAnsibleApi* | [**create**](docs/RepositoriesAnsibleApi.md#create) | **POST** /pulp/api/v3/repositories/ansible/ansible/ | Create an ansible repository
*RepositoriesAnsibleApi* | [**delete**](docs/RepositoriesAnsibleApi.md#delete) | **DELETE** {ansible_ansible_repository_href} | Delete an ansible repository
*RepositoriesAnsibleApi* | [**list**](docs/RepositoriesAnsibleApi.md#list) | **GET** /pulp/api/v3/repositories/ansible/ansible/ | List ansible repositorys
*RepositoriesAnsibleApi* | [**modify**](docs/RepositoriesAnsibleApi.md#modify) | **POST** {ansible_ansible_repository_href}modify/ | Modify Repository Content
*RepositoriesAnsibleApi* | [**partial_update**](docs/RepositoriesAnsibleApi.md#partial_update) | **PATCH** {ansible_ansible_repository_href} | Update an ansible repository
*RepositoriesAnsibleApi* | [**read**](docs/RepositoriesAnsibleApi.md#read) | **GET** {ansible_ansible_repository_href} | Inspect an ansible repository
*RepositoriesAnsibleApi* | [**sync**](docs/RepositoriesAnsibleApi.md#sync) | **POST** {ansible_ansible_repository_href}sync/ | 
*RepositoriesAnsibleApi* | [**update**](docs/RepositoriesAnsibleApi.md#update) | **PUT** {ansible_ansible_repository_href} | Update an ansible repository
*RepositoriesAnsibleVersionsApi* | [**delete**](docs/RepositoriesAnsibleVersionsApi.md#delete) | **DELETE** {ansible_ansible_repository_version_href} | Delete a repository version
*RepositoriesAnsibleVersionsApi* | [**list**](docs/RepositoriesAnsibleVersionsApi.md#list) | **GET** {ansible_ansible_repository_href}versions/ | List repository versions
*RepositoriesAnsibleVersionsApi* | [**read**](docs/RepositoriesAnsibleVersionsApi.md#read) | **GET** {ansible_ansible_repository_version_href} | Inspect a repository version
*RepositoriesAnsibleVersionsApi* | [**repair**](docs/RepositoriesAnsibleVersionsApi.md#repair) | **POST** {ansible_ansible_repository_version_href}repair/ | 
*VersionsApi* | [**get**](docs/VersionsApi.md#get) | **GET** {ansible_role_href}versions/ | 
*VersionsApi* | [**get_0**](docs/VersionsApi.md#get_0) | **GET** {ansible_collection_version_href}versions/ | 


## Documentation For Models

 - [AnsibleAnsibleDistribution](docs/AnsibleAnsibleDistribution.md)
 - [AnsibleAnsibleDistributionResponse](docs/AnsibleAnsibleDistributionResponse.md)
 - [AnsibleAnsibleRepository](docs/AnsibleAnsibleRepository.md)
 - [AnsibleAnsibleRepositoryResponse](docs/AnsibleAnsibleRepositoryResponse.md)
 - [AnsibleCollectionRemote](docs/AnsibleCollectionRemote.md)
 - [AnsibleCollectionRemoteResponse](docs/AnsibleCollectionRemoteResponse.md)
 - [AnsibleCollectionResponse](docs/AnsibleCollectionResponse.md)
 - [AnsibleCollectionVersion](docs/AnsibleCollectionVersion.md)
 - [AnsibleCollectionVersionResponse](docs/AnsibleCollectionVersionResponse.md)
 - [AnsibleRepositorySyncURL](docs/AnsibleRepositorySyncURL.md)
 - [AnsibleRole](docs/AnsibleRole.md)
 - [AnsibleRoleRemote](docs/AnsibleRoleRemote.md)
 - [AnsibleRoleRemoteResponse](docs/AnsibleRoleRemoteResponse.md)
 - [AnsibleRoleResponse](docs/AnsibleRoleResponse.md)
 - [AnsibleTagResponse](docs/AnsibleTagResponse.md)
 - [ArtifactRefResponse](docs/ArtifactRefResponse.md)
 - [AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [CollectionImportDetailResponse](docs/CollectionImportDetailResponse.md)
 - [CollectionMetadataResponse](docs/CollectionMetadataResponse.md)
 - [CollectionNamespaceResponse](docs/CollectionNamespaceResponse.md)
 - [CollectionOneShot](docs/CollectionOneShot.md)
 - [CollectionRefResponse](docs/CollectionRefResponse.md)
 - [CollectionResponse](docs/CollectionResponse.md)
 - [CollectionVersionDocsResponse](docs/CollectionVersionDocsResponse.md)
 - [CollectionVersionResponse](docs/CollectionVersionResponse.md)
 - [ContentSummary](docs/ContentSummary.md)
 - [ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [Copy](docs/Copy.md)
 - [GalaxyCollection](docs/GalaxyCollection.md)
 - [GalaxyCollectionResponse](docs/GalaxyCollectionResponse.md)
 - [GalaxyCollectionVersionResponse](docs/GalaxyCollectionVersionResponse.md)
 - [GalaxyRoleResponse](docs/GalaxyRoleResponse.md)
 - [GalaxyRoleVersionResponse](docs/GalaxyRoleVersionResponse.md)
 - [PaginatedCollectionResponseList](docs/PaginatedCollectionResponseList.md)
 - [PaginatedCollectionResponseListLinks](docs/PaginatedCollectionResponseListLinks.md)
 - [PaginatedCollectionResponseListMeta](docs/PaginatedCollectionResponseListMeta.md)
 - [PaginatedCollectionVersionResponseList](docs/PaginatedCollectionVersionResponseList.md)
 - [PaginatedGalaxyCollectionResponseList](docs/PaginatedGalaxyCollectionResponseList.md)
 - [PaginatedGalaxyCollectionVersionResponseList](docs/PaginatedGalaxyCollectionVersionResponseList.md)
 - [PaginatedGalaxyRoleResponseList](docs/PaginatedGalaxyRoleResponseList.md)
 - [PaginatedGalaxyRoleVersionResponseList](docs/PaginatedGalaxyRoleVersionResponseList.md)
 - [PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PaginatedTagResponseList](docs/PaginatedTagResponseList.md)
 - [PaginatedansibleAnsibleDistributionResponseList](docs/PaginatedansibleAnsibleDistributionResponseList.md)
 - [PaginatedansibleAnsibleRepositoryResponseList](docs/PaginatedansibleAnsibleRepositoryResponseList.md)
 - [PaginatedansibleCollectionRemoteResponseList](docs/PaginatedansibleCollectionRemoteResponseList.md)
 - [PaginatedansibleCollectionResponseList](docs/PaginatedansibleCollectionResponseList.md)
 - [PaginatedansibleCollectionVersionResponseList](docs/PaginatedansibleCollectionVersionResponseList.md)
 - [PaginatedansibleRoleRemoteResponseList](docs/PaginatedansibleRoleRemoteResponseList.md)
 - [PaginatedansibleRoleResponseList](docs/PaginatedansibleRoleResponseList.md)
 - [PatchedansibleAnsibleDistribution](docs/PatchedansibleAnsibleDistribution.md)
 - [PatchedansibleAnsibleRepository](docs/PatchedansibleAnsibleRepository.md)
 - [PatchedansibleCollectionRemote](docs/PatchedansibleCollectionRemote.md)
 - [PatchedansibleRoleRemote](docs/PatchedansibleRoleRemote.md)
 - [PolicyEnum](docs/PolicyEnum.md)
 - [RepoMetadataResponse](docs/RepoMetadataResponse.md)
 - [RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [RepositoryVersion](docs/RepositoryVersion.md)
 - [RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [TagResponse](docs/TagResponse.md)
 - [UnpaginatedCollectionVersionResponse](docs/UnpaginatedCollectionVersionResponse.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## cookieAuth

- **Type**: API key
- **API key parameter name**: Session
- **Location**: 


## Author

pulp-list@redhat.com


